/******************************************************************************
 SyGGlobals.h

 *****************************************************************************/

#ifndef _H_SyGGlobals
#define _H_SyGGlobals

// we include these for convenience

#include <JString.h>

#include <jXGlobals.h>
#include <jTypes.h>
#include <JXTextClipboard.h>

class SyGApplication;
class SyGPrefsMgr;
class SyGBindingsManager;
class SyGViewManPageDialog;
class SyGChooseSaveFile;

SyGApplication*			SyGGetApplication();
SyGPrefsMgr*			SyGGetPrefsMgr();
SyGBindingsManager*		SyGGetBindingsMgr();
SyGViewManPageDialog*	SyGGetManPageDialog();
SyGChooseSaveFile*		SyGGetChooseSaveFile();

void SyGHandleFileAction(const JString& fileName, JBoolean metaOn);
void SyGHandleCustomFileAction(const JString& fileName, const JString& cmd);
void SyGHandleExecutable(const JString& fileName);

	// called by TestApp

JBoolean 	SyGCreateGlobals(SyGApplication* app);
void 		SyGDeleteGlobals();

#endif
